@@ -62,6 +62,9 @@ _CONFIG_DEFAULTS = {
     'demo_data_dir': '.',
     'download_aux': True,
     'sensor_angles_position_preference': 'actual',
+    'readers': {
+        'clip_negative_radiances': False,
+    },
 }
 
 # Satpy main configuration object
