@@ -17,7 +17,7 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Utilities for dealing with ancillary variables."""
 
-from .dataid import DataID
+from .dataid import DataID, default_id_keys_config
 
 
 def dataset_walker(datasets):
@@ -39,7 +39,11 @@ def replace_anc(dataset, parent_dataset):
     """Replace *dataset* the *parent_dataset*'s `ancillary_variables` field."""
     if parent_dataset is None:
         return
-    id_keys = parent_dataset.attrs.get('_satpy_id_keys', dataset.attrs.get('_satpy_id_keys'))
+    id_keys = parent_dataset.attrs.get(
+            '_satpy_id_keys',
+            dataset.attrs.get(
+                '_satpy_id_keys',
+                default_id_keys_config))
     current_dataid = DataID(id_keys, **dataset.attrs)
     for idx, ds in enumerate(parent_dataset.attrs['ancillary_variables']):
         if current_dataid == DataID(id_keys, **ds.attrs):
