@@ -45,12 +45,14 @@ import xarray as xr
 from pyproj import CRS
 from pyresample.geometry import AreaDefinition
 
-from satpy import CHUNK_SIZE
 from satpy._compat import cached_property
 from satpy.readers.file_handlers import BaseFileHandler
+from satpy.utils import get_legacy_chunk_size
 
 logger = logging.getLogger(__name__)
 
+CHUNK_SIZE = get_legacy_chunk_size()
+
 
 class GAASPFileHandler(BaseFileHandler):
     """Generic file handler for GAASP output files."""
