@@ -35,11 +35,13 @@ except ImportError as e:
         """Missing eccodes-python and/or eccodes C-library installation. Use conda to install eccodes.
            Error: """, e)
 
-from satpy import CHUNK_SIZE
 from satpy.readers.file_handlers import BaseFileHandler
+from satpy.utils import get_legacy_chunk_size
 
 logger = logging.getLogger('AscatSoilMoistureBufr')
 
+CHUNK_SIZE = get_legacy_chunk_size()
+
 
 class AscatSoilMoistureBufr(BaseFileHandler):
     """File handler for the ASCAT Soil Moisture BUFR product."""
