@@ -24,12 +24,13 @@ import netCDF4
 import numpy as np
 import xarray as xr
 
-from satpy import CHUNK_SIZE
 from satpy.readers import open_file_or_filename
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.utils import np2str
+from satpy.utils import get_legacy_chunk_size
 
 LOG = logging.getLogger(__name__)
+CHUNK_SIZE = get_legacy_chunk_size()
 
 
 class NetCDF4FileHandler(BaseFileHandler):
