@@ -51,6 +51,10 @@ from satpy.readers import open_file_or_filename
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.utils import angle2xyz, get_legacy_chunk_size, xyz2angle
 
+DEFAULT_MASK_ITEMS = ["INVALID", "SNOW_ICE", "INLAND_WATER", "SUSPECT",
+                      "AC_FAIL", "CLOUD", "HISOLZEN", "OCNN_FAIL",
+                      "CLOUD_MARGIN", "CLOUD_AMBIGUOUS", "LOWRW", "LAND"]
+
 logger = logging.getLogger(__name__)
 
 CHUNK_SIZE = get_legacy_chunk_size()
@@ -100,7 +104,7 @@ class NCOLCIBase(BaseFileHandler):
     cols_name = "columns"
 
     def __init__(self, filename, filename_info, filetype_info,
-                 engine=None):
+                 engine=None, **kwargs):
         """Init the olci reader base."""
         super().__init__(filename, filename_info, filetype_info)
         self._engine = engine
@@ -203,6 +207,12 @@ class NCOLCI1B(NCOLCIChannelBase):
 class NCOLCI2(NCOLCIChannelBase):
     """File handler for OLCI l2."""
 
+    def __init__(self, filename, filename_info, filetype_info, engine=None, unlog=False, mask_items=None):
+        """Init the file handler."""
+        super().__init__(filename, filename_info, filetype_info, engine)
+        self.unlog = unlog
+        self.mask_items = mask_items
+
     def get_dataset(self, key, info):
         """Load a dataset."""
         if self.channel is not None and self.channel != key['name']:
@@ -216,19 +226,28 @@ class NCOLCI2(NCOLCIChannelBase):
         if key['name'] == 'wqsf':
             dataset.attrs['_FillValue'] = 1
         elif key['name'] == 'mask':
-            dataset = self.getbitmask(dataset)
-
+            dataset = self.getbitmask(dataset, self.mask_items)
         dataset.attrs['platform_name'] = self.platform_name
         dataset.attrs['sensor'] = self.sensor
         dataset.attrs.update(key.to_dict())
+        if self.unlog:
+            dataset = self.delog(dataset)
+
         return dataset
 
+    def delog(self, data_array):
+        """Remove log10 from the units and values."""
+        units = data_array.attrs["units"]
+
+        if units.startswith("lg("):
+            data_array = 10 ** data_array
+            data_array.attrs["units"] = units.split("lg(re ")[1].strip(")")
+        return data_array
+
     def getbitmask(self, wqsf, items=None):
         """Get the bitmask."""
         if items is None:
-            items = ["INVALID", "SNOW_ICE", "INLAND_WATER", "SUSPECT",
-                     "AC_FAIL", "CLOUD", "HISOLZEN", "OCNN_FAIL",
-                     "CLOUD_MARGIN", "CLOUD_AMBIGUOUS", "LOWRW", "LAND"]
+            items = DEFAULT_MASK_ITEMS
         bflags = BitFlags(wqsf)
         return reduce(np.logical_or, [bflags[item] for item in items])
 
@@ -240,7 +259,7 @@ class NCOLCILowResData(NCOLCIBase):
     cols_name = "tie_columns"
 
     def __init__(self, filename, filename_info, filetype_info,
-                 engine=None):
+                 engine=None, **kwargs):
         """Init the file handler."""
         super().__init__(filename, filename_info, filetype_info, engine)
         self.l_step = self.nc.attrs['al_subsampling_factor']
