@@ -88,10 +88,12 @@ class TestEnhancementStretch:
     @pytest.mark.parametrize("input_data_name", ["ch1", "ch2", "rgb"])
     def test_apply_enhancement(self, input_data_name, decorator, exp_call_cls):
         """Test the 'apply_enhancement' utility function."""
+
         def _enh_func(img):
             def _calc_func(data):
                 assert isinstance(data, exp_call_cls)
                 return data
+
             decorated_func = decorator(_calc_func)
             return decorated_func(img.data)
 
@@ -224,7 +226,7 @@ class TestEnhancementStretch:
         cmap1 = {'colors': 'blues', 'min_value': 0,
                  'max_value': 1}
         kwargs = {'palettes': [cmap1]}
-        with mock.patch('satpy.enhancements.create_colormap', create_colormap_mock),\
+        with mock.patch('satpy.enhancements.create_colormap', create_colormap_mock), \
                 mock.patch('trollimage.colormap.blues', ret_map):
             _ = mcp(kwargs)
         create_colormap_mock.assert_called_once()
@@ -449,6 +451,7 @@ class TestColormapLoading:
 
 def test_on_separate_bands():
     """Test the `on_separate_bands` decorator."""
+
     def func(array, index, gain=2):
         return xr.DataArray(np.ones(array.shape, dtype=array.dtype) * index * gain,
                             coords=array.coords, dims=array.dims, attrs=array.attrs)
@@ -461,6 +464,7 @@ def test_on_separate_bands():
 
 def test_using_map_blocks():
     """Test the `using_map_blocks` decorator."""
+
     def func(np_array, block_info=None):
         value = block_info[0]['chunk-location'][-1]
         return np.ones(np_array.shape) * value
@@ -474,6 +478,7 @@ def test_using_map_blocks():
 
 def test_on_dask_array():
     """Test the `on_dask_array` decorator."""
+
     def func(dask_array):
         if not isinstance(dask_array, da.core.Array):
             pytest.fail("Array is not a dask array")
@@ -493,83 +498,83 @@ def fake_area():
 
 
 _nwcsaf_geo_props = {
-     'cma_geo': ("geo", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
-     'cma_pps': ("pps", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
-     'cma_extended_pps': ("pps", "cma_extended", None, 'cma_extended_pal', None,
-                          'cloudmask_extended', 'CMA', "uint8"),
-     'cmaprob_pps': ("pps", "cmaprob", None, 'cmaprob_pal', None, 'cloudmask_probability',
-                     'CMAPROB', "uint8"),
-     'ct_geo': ("geo", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
-     'ct_pps': ("pps", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
-     'ctth_alti_geo': ("geo", "ctth_alti", None, 'ctth_alti_pal', None, 'cloud_top_height',
+    'cma_geo': ("geo", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
+    'cma_pps': ("pps", "cma", None, 'cma_pal', None, 'cloudmask', 'CMA', "uint8"),
+    'cma_extended_pps': ("pps", "cma_extended", None, 'cma_extended_pal', None,
+                         'cloudmask_extended', 'CMA', "uint8"),
+    'cmaprob_pps': ("pps", "cmaprob", None, 'cmaprob_pal', None, 'cloudmask_probability',
+                    'CMAPROB', "uint8"),
+    'ct_geo': ("geo", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
+    'ct_pps': ("pps", "ct", None, 'ct_pal', None, 'cloudtype', 'CT', "uint8"),
+    'ctth_alti_geo': ("geo", "ctth_alti", None, 'ctth_alti_pal', None, 'cloud_top_height',
+                      'CTTH', "float64"),
+    'ctth_alti_pps': ("pps", "ctth_alti", None, 'ctth_alti_pal', "ctth_status_flag",
+                      'cloud_top_height', 'CTTH', "float64"),
+    'ctth_pres_geo': ("geo", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
+                      'CTTH', "float64"),
+    'ctth_pres_pps': ("pps", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
+                      'CTTH', "float64"),
+    'ctth_tempe_geo': ("geo", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
                        'CTTH', "float64"),
-     'ctth_alti_pps': ("pps", "ctth_alti", None, 'ctth_alti_pal', "ctth_status_flag",
-                       'cloud_top_height', 'CTTH', "float64"),
-     'ctth_pres_geo': ("geo", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
+    'ctth_tempe_pps': ("pps", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
                        'CTTH', "float64"),
-     'ctth_pres_pps': ("pps", "ctth_pres", None, 'ctth_pres_pal', None, 'cloud_top_pressure',
-                       'CTTH', "float64"),
-     'ctth_tempe_geo': ("geo", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
-                        'CTTH', "float64"),
-     'ctth_tempe_pps': ("pps", "ctth_tempe", None, 'ctth_tempe_pal', None, 'cloud_top_temperature',
-                        'CTTH', "float64"),
-     'cmic_phase_geo': ("geo", "cmic_phase", None, 'cmic_phase_pal', None, 'cloud_top_phase',
-                        'CMIC', "uint8"),
-     'cmic_phase_pps': ("pps", "cmic_phase", None, 'cmic_phase_pal', "cmic_status_flag", 'cloud_top_phase',
-                        'CMIC', "uint8"),
-     'cmic_reff_geo': ("geo", "cmic_reff", None, 'cmic_reff_pal', None, 'cloud_drop_effective_radius',
-                       'CMIC', "float64"),
-     'cmic_reff_pps': ("pps", "cmic_reff", "cmic_cre", 'cmic_cre_pal', "cmic_status_flag",
-                       'cloud_drop_effective_radius', 'CMIC', "float64"),
-     'cmic_cot_geo': ("geo", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
+    'cmic_phase_geo': ("geo", "cmic_phase", None, 'cmic_phase_pal', None, 'cloud_top_phase',
+                       'CMIC', "uint8"),
+    'cmic_phase_pps': ("pps", "cmic_phase", None, 'cmic_phase_pal', "cmic_status_flag", 'cloud_top_phase',
+                       'CMIC', "uint8"),
+    'cmic_reff_geo': ("geo", "cmic_reff", None, 'cmic_reff_pal', None, 'cloud_drop_effective_radius',
                       'CMIC', "float64"),
-     'cmic_cot_pps': ("pps", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
-                      'CMIC', "float64"),
-     'cmic_cwp_pps': ("pps", "cmic_cwp", None, 'cmic_cwp_pal', None, 'cloud_water_path',
-                      'CMIC', "float64"),
-     'cmic_lwp_geo': ("geo", "cmic_lwp", None, 'cmic_lwp_pal', None, 'cloud_liquid_water_path',
-                      'CMIC', "float64"),
-     'cmic_lwp_pps': ("pps", "cmic_lwp", None, 'cmic_lwp_pal', None, 'liquid_water_path',
-                      'CMIC', "float64"),
-     'cmic_iwp_geo': ("geo", "cmic_iwp", None, 'cmic_iwp_pal', None, 'cloud_ice_water_path',
-                      'CMIC', "float64"),
-     'cmic_iwp_pps': ("pps", "cmic_iwp", None, 'cmic_iwp_pal', None, 'ice_water_path',
-                      'CMIC', "float64"),
-     'pc': ("geo", "pc", None, 'pc_pal', None, 'precipitation_probability', 'PC', "uint8"),
-     'crr': ("geo", "crr", None, 'crr_pal', None, 'convective_rain_rate', 'CRR', "uint8"),
-     'crr_accum': ("geo", "crr_accum", None, 'crr_pal', None,
-                   'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
-     'ishai_tpw': ("geo", "ishai_tpw", None, 'ishai_tpw_pal', None, 'total_precipitable_water',
-                   'iSHAI', "float64"),
-     'ishai_shw': ("geo", "ishai_shw", None, 'ishai_shw_pal', None, 'showalter_index',
-                   'iSHAI', "float64"),
-     'ishai_li': ("geo", "ishai_li", None, 'ishai_li_pal', None, 'lifted_index',
+    'cmic_reff_pps': ("pps", "cmic_reff", "cmic_cre", 'cmic_cre_pal', "cmic_status_flag",
+                      'cloud_drop_effective_radius', 'CMIC', "float64"),
+    'cmic_cot_geo': ("geo", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
+                     'CMIC', "float64"),
+    'cmic_cot_pps': ("pps", "cmic_cot", None, 'cmic_cot_pal', None, 'cloud_optical_thickness',
+                     'CMIC', "float64"),
+    'cmic_cwp_pps': ("pps", "cmic_cwp", None, 'cmic_cwp_pal', None, 'cloud_water_path',
+                     'CMIC', "float64"),
+    'cmic_lwp_geo': ("geo", "cmic_lwp", None, 'cmic_lwp_pal', None, 'cloud_liquid_water_path',
+                     'CMIC', "float64"),
+    'cmic_lwp_pps': ("pps", "cmic_lwp", None, 'cmic_lwp_pal', None, 'liquid_water_path',
+                     'CMIC', "float64"),
+    'cmic_iwp_geo': ("geo", "cmic_iwp", None, 'cmic_iwp_pal', None, 'cloud_ice_water_path',
+                     'CMIC', "float64"),
+    'cmic_iwp_pps': ("pps", "cmic_iwp", None, 'cmic_iwp_pal', None, 'ice_water_path',
+                     'CMIC', "float64"),
+    'pc': ("geo", "pc", None, 'pc_pal', None, 'precipitation_probability', 'PC', "uint8"),
+    'crr': ("geo", "crr", None, 'crr_pal', None, 'convective_rain_rate', 'CRR', "uint8"),
+    'crr_accum': ("geo", "crr_accum", None, 'crr_pal', None,
+                  'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
+    'ishai_tpw': ("geo", "ishai_tpw", None, 'ishai_tpw_pal', None, 'total_precipitable_water',
                   'iSHAI', "float64"),
-     'ci_prob30': ("geo", "ci_prob30", None, 'ci_pal', None, 'convection_initiation_prob30',
-                   'CI', "float64"),
-     'ci_prob60': ("geo", "ci_prob60", None, 'ci_pal', None, 'convection_initiation_prob60',
-                   'CI', "float64"),
-     'ci_prob90': ("geo", "ci_prob90", None, 'ci_pal', None, 'convection_initiation_prob90',
-                   'CI', "float64"),
-     'asii_turb_trop_prob': ("geo", "asii_turb_trop_prob", None, 'asii_turb_prob_pal', None,
-                             'asii_prob', 'ASII-NG', "float64"),
-     'MapCellCatType': ("geo", "MapCellCatType", None, 'MapCellCatType_pal', None,
-                        'rdt_cell_type', 'RDT-CW', "uint8"),
-     }
+    'ishai_shw': ("geo", "ishai_shw", None, 'ishai_shw_pal', None, 'showalter_index',
+                  'iSHAI', "float64"),
+    'ishai_li': ("geo", "ishai_li", None, 'ishai_li_pal', None, 'lifted_index',
+                 'iSHAI', "float64"),
+    'ci_prob30': ("geo", "ci_prob30", None, 'ci_pal', None, 'convection_initiation_prob30',
+                  'CI', "float64"),
+    'ci_prob60': ("geo", "ci_prob60", None, 'ci_pal', None, 'convection_initiation_prob60',
+                  'CI', "float64"),
+    'ci_prob90': ("geo", "ci_prob90", None, 'ci_pal', None, 'convection_initiation_prob90',
+                  'CI', "float64"),
+    'asii_turb_trop_prob': ("geo", "asii_turb_trop_prob", None, 'asii_turb_prob_pal', None,
+                            'asii_prob', 'ASII-NG', "float64"),
+    'MapCellCatType': ("geo", "MapCellCatType", None, 'MapCellCatType_pal', None,
+                       'rdt_cell_type', 'RDT-CW', "uint8"),
+}
 
 
 @pytest.mark.parametrize(
-        "data",
-        ['cma_geo', 'cma_pps', 'cma_extended_pps', 'cmaprob_pps', 'ct_geo',
-            'ct_pps', 'ctth_alti_geo', 'ctth_alti_pps', 'ctth_pres_geo',
-            'ctth_pres_pps', 'ctth_tempe_geo', 'ctth_tempe_pps',
-            'cmic_phase_geo', 'cmic_phase_pps', 'cmic_reff_geo',
-            'cmic_reff_pps', 'cmic_cot_geo', 'cmic_cot_pps', 'cmic_cwp_pps',
-            'cmic_lwp_geo', 'cmic_lwp_pps', 'cmic_iwp_geo', 'cmic_iwp_pps',
-            'pc', 'crr', 'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li',
-            'ci_prob30', 'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob',
-            'MapCellCatType']
-        )
+    "data",
+    ['cma_geo', 'cma_pps', 'cma_extended_pps', 'cmaprob_pps', 'ct_geo',
+     'ct_pps', 'ctth_alti_geo', 'ctth_alti_pps', 'ctth_pres_geo',
+     'ctth_pres_pps', 'ctth_tempe_geo', 'ctth_tempe_pps',
+     'cmic_phase_geo', 'cmic_phase_pps', 'cmic_reff_geo',
+     'cmic_reff_pps', 'cmic_cot_geo', 'cmic_cot_pps', 'cmic_cwp_pps',
+     'cmic_lwp_geo', 'cmic_lwp_pps', 'cmic_iwp_geo', 'cmic_iwp_pps',
+     'pc', 'crr', 'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li',
+     'ci_prob30', 'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob',
+     'MapCellCatType']
+)
 def test_nwcsaf_comps(fake_area, tmp_path, data):
     """Test loading NWCSAF composites."""
     from satpy.writers import get_enhanced_image
@@ -589,40 +594,41 @@ def test_nwcsaf_comps(fake_area, tmp_path, data):
     # create a minimally fake netCDF file, otherwise satpy won't load the
     # composite
     ds = xr.Dataset(
-            coords={"nx": [0], "ny": [0]},
-            attrs={
-                "source": "satpy unit test",
-                "time_coverage_start": "0001-01-01T00:00:00Z",
-                "time_coverage_end": "0001-01-01T01:00:00Z",
-                }
-            )
+        coords={"nx": [0], "ny": [0]},
+        attrs={
+            "source": "satpy unit test",
+            "time_coverage_start": "0001-01-01T00:00:00Z",
+            "time_coverage_end": "0001-01-01T01:00:00Z",
+        }
+    )
     ds.attrs.update(id_)
     ds.to_netcdf(fk)
     sc = Scene(filenames=[os.fspath(fk)], reader=[reader])
     sc[palettename] = xr.DataArray(
-            da.tile(da.arange(256), [3, 1]).T,
-            dims=("pal02_colors", "pal_RGB"))
+        da.tile(da.arange(256), [3, 1]).T,
+        dims=("pal02_colors", "pal_RGB"))
     fake_alti = da.linspace(rng[0], rng[1], 4, chunks=2, dtype=dtp).reshape(2, 2)
     ancvars = [sc[palettename]]
     if statusname is not None:
         sc[statusname] = xr.DataArray(
-                da.zeros(shape=(2, 2), dtype="uint8"),
-                attrs={
-                    "area": fake_area,
-                    "_FillValue": 123},
-                dims=("y", "x"))
-        ancvars.append(sc[statusname])
-    sc[dvname] = xr.DataArray(
-            fake_alti,
-            dims=("y", "x"),
+            da.zeros(shape=(2, 2), dtype="uint8"),
             attrs={
                 "area": fake_area,
-                "scaled_FillValue": 123,
-                "ancillary_variables": ancvars,
-                "valid_range": rng})
+                "_FillValue": 123},
+            dims=("y", "x"))
+        ancvars.append(sc[statusname])
+    sc[dvname] = xr.DataArray(
+        fake_alti,
+        dims=("y", "x"),
+        attrs={
+            "area": fake_area,
+            "scaled_FillValue": 123,
+            "ancillary_variables": ancvars,
+            "valid_range": rng})
 
     def _fake_get_varname(info, info_type="file_key"):
         return altname or dvname
+
     with mock.patch("satpy.readers.nwcsaf_nc.NcNWCSAF._get_varname_in_file") as srnN_:
         srnN_.side_effect = _fake_get_varname
         sc.load([comp])
@@ -632,7 +638,49 @@ def test_nwcsaf_comps(fake_area, tmp_path, data):
         np.testing.assert_array_equal(im.data.coords["bands"], ["P"])
         if dtp == "float64":
             np.testing.assert_allclose(
-                    im.data.sel(bands="P"),
-                    ((fake_alti - rng[0]) * (255/np.ptp(rng))).round())
+                im.data.sel(bands="P"),
+                ((fake_alti - rng[0]) * (255 / np.ptp(rng))).round())
         else:
             np.testing.assert_allclose(im.data.sel(bands="P"), fake_alti)
+
+
+class TestTCREnhancement:
+    """Test the AHI enhancement functions."""
+
+    def setup_method(self):
+        """Create test data."""
+        data = da.arange(-100, 1000, 110).reshape(2, 5)
+        rgb_data = np.stack([data, data, data])
+        self.rgb = xr.DataArray(rgb_data, dims=('bands', 'y', 'x'),
+                                coords={'bands': ['R', 'G', 'B']},
+                                attrs={'platform_name': 'Himawari-8'})
+
+    def test_jma_true_color_reproduction(self):
+        """Test the jma_true_color_reproduction enhancement."""
+        from trollimage.xrimage import XRImage
+
+        from satpy.enhancements import jma_true_color_reproduction
+
+        expected = [[[-109.93, 10.993, 131.916, 252.839, 373.762],
+                     [494.685, 615.608, 736.531, 857.454, 978.377]],
+
+                    [[-97.73, 9.773, 117.276, 224.779, 332.282],
+                     [439.785, 547.288, 654.791, 762.294, 869.797]],
+
+                    [[-93.29, 9.329, 111.948, 214.567, 317.186],
+                     [419.805, 522.424, 625.043, 727.662, 830.281]]]
+
+        img = XRImage(self.rgb)
+        jma_true_color_reproduction(img)
+
+        np.testing.assert_almost_equal(img.data.compute(), expected)
+
+        self.rgb.attrs['platform_name'] = None
+        img = XRImage(self.rgb)
+        with pytest.raises(ValueError, match="Missing platform name."):
+            jma_true_color_reproduction(img)
+
+        self.rgb.attrs['platform_name'] = 'Fakesat'
+        img = XRImage(self.rgb)
+        with pytest.raises(KeyError, match="No conversion matrix found for platform Fakesat"):
+            jma_true_color_reproduction(img)
