@@ -63,8 +63,10 @@ class Test_SeviriL2GribFileHandler(unittest.TestCase):
     @mock.patch('satpy.readers.seviri_l2_grib.da')
     def test_data_reading(self, da_, xr_):
         """Test the reading of data from the product."""
-        from satpy import CHUNK_SIZE
         from satpy.readers.seviri_l2_grib import REPEAT_CYCLE_DURATION, SeviriL2GribFileHandler
+        from satpy.utils import get_legacy_chunk_size
+        CHUNK_SIZE = get_legacy_chunk_size()
+
         with mock.patch("builtins.open", mock.mock_open()) as mock_file:
             with mock.patch('satpy.readers.seviri_l2_grib.ec', self.ec_):
                 self.reader = SeviriL2GribFileHandler(
